@@ -11,6 +11,7 @@ from .setup_info import SETUP_INFO
 
 from .configure import configure
 from .startsite import startsite
+from .startproject import startproject
 from .list import list
 
 @click.group(help="""
@@ -24,6 +25,7 @@ def main():
 
 main.add_command(configure)
 main.add_command(startsite)
+main.add_command(startproject)
 main.add_command(list)
 
 if __name__ == '__main__':
